# Copyright (C) 2011, Aleksey Lim
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Common defines."""

from gettext import gettext as _

from libmace import util


VERSION = '1.1'

source = util.Option(
        _('path to the root directory with configuration templates'),
        default='/etc/mace', short_option='-s')

output = util.Option(
        _('path to the root directory with configuration templates'),
        default='/', short_option='-o')

templates = util.Option(
        _('path to the configuration templates'),
        default='/usr/share/sugar-server-templates', short_option='-t')

dry_services = util.Option(
        _('do not ask providers to apply configuration, just write ' \
                'configuration files'),
        default=False, type_cast=bool, short_option='-S', action='store_true')

no_rollback = util.Option(
        _('do not rollback configuration on error, might be useful ' \
                'while debugging'),
        default=False, type_cast=bool, short_option='-R', action='store_true')

include = util.Option(
        _('colon separated list of providers to only enable'),
        short_option='-I',
        type_cast=util.Option.list_cast, type_repr=util.Option.list_repr)

exclude = util.Option(
        _('colon separated list of providers to disable'),
        short_option='-X',
        type_cast=util.Option.list_cast, type_repr=util.Option.list_repr)

keywords = util.Option(
        _('colon separated list of keywords to include configs for'),
        default='production', short_option='-K',
        type_cast=util.Option.list_cast, type_repr=util.Option.list_repr)

unattended = util.Option(
        _('process providers to keep final configuration unattended'),
        default=True, type_cast=bool, action='store_true')

distributor_id = util.Option(
        _('LSB Distributor ID instead of auto detecting'),
        short_option='-d')

release = util.Option(
        _('LSB Release instead of auto detecting'),
        short_option='-r')

force = util.Option(
        _('force to rewrite configuration and reapply it'),
        default=False, type_cast=bool, short_option='-f', action='store_true')

debug = util.Option(
        _('debug logging level; multiple argument'),
        default=0, type_cast=int, short_option='-D', action='count')

util.Option.seek('main')
