# Copyright (C) 2011, Aleksey Lim
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
OpenSSH
-------

Mace configuration:
    :Service:
        ``openssh.d``
    :Confiles:
        - ``ssh_config``
        - ``sshd_config``
    :Variables:
        No

Final configuration for all distributions:
    :Replaces:
        - ``/etc/ssh/ssh_config``
        - ``/etc/ssh/sshd_config``

"""
from libmace.providers import BaseProvider


class Provider(BaseProvider):

    DISTRO_MAP = {
            ('Fedora', None): {
                'service': 'sshd',
                },
            ('Ubuntu', None): {
                'service': 'ssh',
                },
            }

    @property
    def comment(self):
        return '#'

    @property
    def name(self):
        return 'openssh'

    def get_requires(self, conftext):
        return ['openssh-server']

    @property
    def confiles(self):
        return ['ssh_config', 'sshd_config']

    def confpath(self, confile=None):
        return '/etc/ssh/%s' % confile
